Class: AurePay::DepositCreate

Inherits:
ApiModelBase show all
Defined in:
lib/aurepay/generated/models/deposit_create.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ DepositCreate

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
# File 'lib/aurepay/generated/models/deposit_create.rb', line 103

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `AurePay::DepositCreate` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `AurePay::DepositCreate`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'method')
    self.method = attributes[:'method']
  else
    self.method = 'pix'
  end

  if attributes.key?(:'amount')
    self.amount = attributes[:'amount']
  else
    self.amount = nil
  end

  if attributes.key?(:'reference')
    self.reference = attributes[:'reference']
  else
    self.reference = nil
  end

  if attributes.key?(:'expiration')
    self.expiration = attributes[:'expiration']
  end

  if attributes.key?(:'callback_url')
    self.callback_url = attributes[:'callback_url']
  end

  if attributes.key?(:'customer')
    self.customer = attributes[:'customer']
  end

  if attributes.key?(:'metadata')
    if (value = attributes[:'metadata']).is_a?(Hash)
      self. = value
    end
  end

  if attributes.key?(:'splits')
    if (value = attributes[:'splits']).is_a?(Array)
      self.splits = value
    end
  end
end

Instance Attribute Details

#amountObject

Valor em centavos (BRL) ou menor unidade USDT



21
22
23
# File 'lib/aurepay/generated/models/deposit_create.rb', line 21

def amount
  @amount
end

#callback_urlObject

Returns the value of attribute callback_url.



27
28
29
# File 'lib/aurepay/generated/models/deposit_create.rb', line 27

def callback_url
  @callback_url
end

#customerObject

Returns the value of attribute customer.



29
30
31
# File 'lib/aurepay/generated/models/deposit_create.rb', line 29

def customer
  @customer
end

#expirationObject

Returns the value of attribute expiration.



25
26
27
# File 'lib/aurepay/generated/models/deposit_create.rb', line 25

def expiration
  @expiration
end

#metadataObject

Returns the value of attribute metadata.



31
32
33
# File 'lib/aurepay/generated/models/deposit_create.rb', line 31

def 
  @metadata
end

#methodObject

Returns the value of attribute method.



18
19
20
# File 'lib/aurepay/generated/models/deposit_create.rb', line 18

def method
  @method
end

#referenceObject

Returns the value of attribute reference.



23
24
25
# File 'lib/aurepay/generated/models/deposit_create.rb', line 23

def reference
  @reference
end

#splitsObject

Returns the value of attribute splits.



33
34
35
# File 'lib/aurepay/generated/models/deposit_create.rb', line 33

def splits
  @splits
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



72
73
74
# File 'lib/aurepay/generated/models/deposit_create.rb', line 72

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



77
78
79
# File 'lib/aurepay/generated/models/deposit_create.rb', line 77

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



58
59
60
61
62
63
64
65
66
67
68
69
# File 'lib/aurepay/generated/models/deposit_create.rb', line 58

def self.attribute_map
  {
    :'method' => :'method',
    :'amount' => :'amount',
    :'reference' => :'reference',
    :'expiration' => :'expiration',
    :'callback_url' => :'callbackUrl',
    :'customer' => :'customer',
    :'metadata' => :'metadata',
    :'splits' => :'splits'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
# File 'lib/aurepay/generated/models/deposit_create.rb', line 247

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



96
97
98
99
# File 'lib/aurepay/generated/models/deposit_create.rb', line 96

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



82
83
84
85
86
87
88
89
90
91
92
93
# File 'lib/aurepay/generated/models/deposit_create.rb', line 82

def self.openapi_types
  {
    :'method' => :'String',
    :'amount' => :'Integer',
    :'reference' => :'String',
    :'expiration' => :'Time',
    :'callback_url' => :'String',
    :'customer' => :'CustomerInput',
    :'metadata' => :'Hash<String, Object>',
    :'splits' => :'Array<Hash<String, Object>>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



219
220
221
222
223
224
225
226
227
228
229
230
# File 'lib/aurepay/generated/models/deposit_create.rb', line 219

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      method == o.method &&
      amount == o.amount &&
      reference == o.reference &&
      expiration == o.expiration &&
      callback_url == o.callback_url &&
      customer == o.customer &&
       == o. &&
      splits == o.splits
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


234
235
236
# File 'lib/aurepay/generated/models/deposit_create.rb', line 234

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



240
241
242
# File 'lib/aurepay/generated/models/deposit_create.rb', line 240

def hash
  [method, amount, reference, expiration, callback_url, customer, , splits].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



162
163
164
165
166
167
168
169
170
171
172
173
174
# File 'lib/aurepay/generated/models/deposit_create.rb', line 162

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @amount.nil?
    invalid_properties.push('invalid value for "amount", amount cannot be nil.')
  end

  if @reference.nil?
    invalid_properties.push('invalid value for "reference", reference cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



269
270
271
272
273
274
275
276
277
278
279
280
281
# File 'lib/aurepay/generated/models/deposit_create.rb', line 269

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



178
179
180
181
182
183
184
185
# File 'lib/aurepay/generated/models/deposit_create.rb', line 178

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  method_validator = EnumAttributeValidator.new('String', ["pix", "usdt"])
  return false unless method_validator.valid?(@method)
  return false if @amount.nil?
  return false if @reference.nil?
  true
end